summaryrefslogtreecommitdiff
path: root/src/graphics.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/graphics.h')
-rw-r--r--src/graphics.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/graphics.h b/src/graphics.h
index b45bc15c..a0749795 100644
--- a/src/graphics.h
+++ b/src/graphics.h
@@ -120,9 +120,9 @@ class Graphics : public gcn::SDLGraphics {
int getHeight();
/**
* takes a screenshot, and saves it as a png
*/
- bool saveScreenshot(char *filename, ...);
+ virtual SDL_Surface* getScreenshot();
protected:
SDL_Surface *mScreen;
@@ -120,9 +120,9 @@ class Graphics : public gcn::SDLGraphics {
int getHeight();
/**
- * takes a screenshot, and saves it as a png
+ * takes a screenshot and returns it as SDL surface
*/